<div align="center">
  <img src="https://storage.googleapis.com/hume-public-logos/hume/hume-banner.png">
  <h1>Hume AI Python SDK</h1>

  <p>
    <strong>Integrate Hume APIs directly into your Python application</strong>
  </p>

  <br>
  <div>
    <a href="https://humeai.github.io/hume-python-sdk"><img src="https://img.shields.io/badge/docs-mkdocs-blue" alt="Docs"></a>
    <a href="https://pepy.tech/project/hume"><img src="https://pepy.tech/badge/hume" alt="Downloads"></a>
    <a href="https://pypi.org/project/hume"><img src="https://img.shields.io/pypi/v/hume?logo=python&logoColor=%23cccccc" alt="PyPI"></a>
    <a href="https://github.com/HumeAI/hume-python-sdk/actions/workflows/ci.yml"><img src="https://github.com/HumeAI/hume-python-sdk/actions/workflows/ci.yaml/badge.svg" alt="CI"></a>
  </div>
  <br>
</div>

To get started, create an account at [beta.hume.ai](https://beta.hume.ai).

> **Note:**
> Our APIs might undergo breaking changes that are necessary for us to improve our tooling and ensure a more reliable release in the future. Early versions of this SDK may have partial support or support may be fully discontinued. We encourage you to [join our Discord](https://link.hume.ai/discord) to to stay up to date with the latest changes.

## Documentation & Examples

For complete documentation check out the [Python SDK docs site](https://humeai.github.io/hume-python-sdk/) or [try our quickstart guide](https://dev.hume.ai/docs/empathic-voice-interface-evi/quickstart/python).

Example notebooks can be found in the [examples folder](./examples/README.md).

## Other Resources

- [Hume AI Homepage](https://hume.ai)
- [Platform Documentation](https://dev.hume.ai)
- [API Reference](https://dev.hume.ai/reference)

## Citations

Hume's expressive communication platform has been built on top of published scientific research. If you use this SDK in your work please cite one of the relevant papers in [our publications repo](https://github.com/HumeAI/hume-research-publications).

## Support

If you have questions, require assistance, or wish to engage in discussions pertaining to this SDK, [reach out to us on Discord](https://link.hume.ai/discord)! For issues specific to this Python SDK, we invite you to [open a new issue on Github](https://github.com/HumeAI/hume-python-sdk/issues/new).
